@@ -38,13 +38,41 @@
 
 #include "pttiff.h"
 
-// MSVC doesn't support round()
+
 #ifdef _MSC_VER
+
+// MSVC doesn't support round()
 //#define round(x) ( (int) (x+0.5) )
 #define round(x) (int)(x)
+
+// MSVC wants htons() to be a library function
+// here we define it as a macro instead
+#undef htons
+#undef htonl
+// byte reordering macros -- avoids loading sockets lib on Windows
+#define LITTLE_ENDIAN	// change if your Windows box is from Mars
+#if defined(BIG_ENDIAN) && !defined(LITTLE_ENDIAN)
+#define htons(A) (A)
+#define htonl(A) (A)
+#define ntohs(A) (A)
+#define ntohl(A) (A)
+#elif defined(LITTLE_ENDIAN) && !defined(BIG_ENDIAN)
+#define htons(A) (((uint16)(A) & 0xff00) >> 8 | ((uint16)(A) & 0x00ff) << 8 )
+#define htonl(A) ((((uint32)(A) & 0xff000000) >> 24) | \
+((uint32)(A) & 0x00ff0000) >> 8 | \
+((uint32)(A) & 0x0000ff00) << 8 | \
+((uint32)(A) & 0x000000ff) << 24)
+#define ntohs htons
+#define ntohl htohl
+#else
+#error "Either BIG_ENDIAN or LITTLE_ENDIAN must be #defined, but not both."
 #endif
 
-FILE *debugFile;
+#endif  //def _MSC_VER
+
+
+
+FILE *debugFile = 0;
 
 
 #ifdef __TESTING__
@@ -89,6 +117,7 @@ magnolia_struct *InitializeMagnolia(int numberImages, int size, calla_function p
     for (j=0; j<6 ; j++) { 
 
       if ((ptrDouble = calloc(size, sizeof(double))) == NULL) {
+        /// @TODO clean up memory leak
         return NULL;
       }
 
@@ -578,6 +607,12 @@ void ColourBrightness(  fullPath *fullPathImages,  fullPath *outputFullPathImage
 
   numberHistograms = ((counterImages-1) * counterImages)/2;
 
+  if(debugFile)
+  {
+    fclose(debugFile);
+    debugFile = 0;
+  }
+
   debugFile = fopen("Debug.txt", "w");
   //  debugFile = stderr;
 
@@ -934,15 +969,15 @@ int ComputeColourBrightnessCorrection(calla_struct *calla)
 {
 
 
-  double *remappedSourceHistogram;
-  double *accumToCorrectHistogram;
-  double *accumSourceHistogram;
-  int *processedImages;
+  double *remappedSourceHistogram   = 0;
+  double *accumToCorrectHistogram   = 0;
+  double *accumSourceHistogram      = 0;
+  int    *processedImages           = 0;
 
   int currentImageNumber;
   int channel;
   int numberIntersections;
-  histograms_struct *currentHistogram;
+  histograms_struct *currentHistogram = 0;
   int j;
 
   int **ptrHistogram;
@@ -964,18 +999,26 @@ int ComputeColourBrightnessCorrection(calla_struct *calla)
   remappedSourceHistogram = malloc(0x100 * sizeof(double));
 
 
-  if ( processedImages == 0 )
+  if ( processedImages == 0
+    || accumToCorrectHistogram == 0
+    || accumSourceHistogram == 0  
+    || remappedSourceHistogram == 0 )
+  {
+    if ( processedImages != 0 )
+      free(processedImages);
+
+    if ( remappedSourceHistogram != 0 )
+      free(remappedSourceHistogram);
+
+    if ( accumToCorrectHistogram != 0 ) 
+      free(accumToCorrectHistogram);
+
+    if ( accumSourceHistogram != 0 )
+      free(accumSourceHistogram);
+
     return 0;
-  
-  if ( accumToCorrectHistogram == 0 ) 
-    return 0;
-  
-  if (accumSourceHistogram == 0 ) 
-    return 0;
-  
-  if (remappedSourceHistogram == 0 )
-    return 0;
-  
+  }
+
   // Mark starting image as done
   processedImages[calla->indexReferenceImage] = 1;
 
@@ -1184,7 +1227,7 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
   int currentRow;
   int otherImage;
   int currentImage;
-  TIFF **ptrTIFFs;
+  TIFF **ptrTIFFs = NULL;
   uint16 samplesPerPixel;
   uint16 bitsPerSample;
   uint32 imageLength;
@@ -1226,7 +1269,10 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
   crop_info_array = (CropInfo *)calloc(numberImages, sizeof(CropInfo));
   
   if ( ptrTIFFs == NULL || crop_info_array == NULL )
-    return 0;
+  {
+    saveReturnValue = 0;
+    goto Exit;
+  }
   
   currentImage = 0;
 
@@ -1235,13 +1281,15 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
 
     if (GetFullPath(&fullPathImages[currentImage],tempString) != 0) {
       PrintError("Could not get filename");
-      return(0);
+      saveReturnValue = 0;
+      goto Exit;
     }
     
     if ((ptrTIFFs[currentImage] = TIFFOpen(tempString, "r")) == NULL) {
       sprintf(tempString2, "Could not open TIFF file [%s]", tempString);
       PrintError(tempString2);
-      return NULL;
+      saveReturnValue = 0;
+      goto Exit;
     }
     
     getCropInformationFromTiff(ptrTIFFs[currentImage], &(crop_info_array[currentImage]));
@@ -1268,7 +1316,8 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
 
   if ( imagesDataBuffer == 0 ) {
     PrintError("Not enough memory");
-    return NULL;
+    saveReturnValue = 0;
+    goto Exit;
   }
 
   currentHistogram = ptrHistograms;
@@ -1294,11 +1343,15 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
       for (i = 0 ;  i < 6 ; i++) {
         
         if ((currentHistogram->ptrBaseHistograms[i] = calloc(currentHistogram->numberDifferentValues, sizeof(int))) == NULL)
-          return 0;
-        
+        {
+          saveReturnValue = 0;
+          goto Exit;
+        }
         if ((currentHistogram->ptrOtherHistograms[i] = calloc(currentHistogram->numberDifferentValues,sizeof(int))) == NULL)
-          return 0;
-        
+        {
+          saveReturnValue = 0;
+          goto Exit;
+        }
       } // for
       
     } //for (otherImage = currentImage + 1; otherImage < numberImages ; otherImage++, currentHistogram++) 
@@ -1323,7 +1376,8 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
             TIFFClose(ptrTIFFs[currentImage]);
             
           } //for
-          return 0;
+          saveReturnValue = 0;
+          goto Exit;
 
         } // progresss
         
@@ -1482,8 +1536,10 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
 
   }
 
+Exit:
   free(ptrTIFFs);
   free(imagesDataBuffer);
+  free(crop_info_array);
 
   return(saveReturnValue);
 }
