@@ -19,10 +19,11 @@ void setFcnPanoNperCP (int i);
 int getFcnPanoNperCP(void);
 void setFcnPanoDoNotInitAvgFov(void);
 void forceFcnPanoReinitAvgFov(void);
-AlignInfo   *GetGlobalPtr();
+AlignInfo   *GetGlobalPtr(void);
 
 // set sigma of huber m-estimator. The influence of
 // control points with errors above sigma is reduced.
 // sigma = 0 disables the m-estimator
 void setFcnPanoHuberSigma(double sigma);
 
+int EvaluateControlPointErrorAndComponents (int num, double *errptr, double errComponent[2]);
