@@ -31,6 +31,7 @@ MODIFICATIONS:
    
 
 #include "filter.h"
+#include <assert.h>
 
 static void 	ShiftImage(TrformStr *TrPtr, int xoff, int yoff);
 static int 		getFrame( Image *im, int *xoff, int *yoff, int width, int height, int showprogress );
@@ -39,7 +40,7 @@ static int      hasUsefulColorParas( cPrefs *cp, int color );
 
 
 
-void 	correct	(TrformStr *TrPtr, cPrefs *prefs) 
+void 	correct (TrformStr *TrPtr, cPrefs *prefs) 
 {
 
 	int 	i=0,j,k, kstart, kend, kdone, color;
@@ -69,6 +70,7 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 
 	// Apply filters, if required
 
+
 	TrPtr->success = 1;
 	
 	if( prefs->luminance )
@@ -572,6 +574,7 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 				fD.func    = execute_stack_new; fD.param    = stack;
                 fDinv.func = execute_stack_new; fDinv.param = stackinv;
                 transFormEx( TrPtr, &fD, &fDinv, k, 1 );
+                i = ii;
 			}
             
             switch(k) // We use k as control var for a little statemachine:
@@ -902,6 +905,23 @@ void SetCorrectDefaults( cPrefs *prefs )
 			prefs->radial_params[i][k] = 0.0;		
 		prefs->lum_params[i]		= 0.0;
 	}
+	prefs->tilt 	=  	FALSE;
+        prefs->tilt_x   = 0;
+        prefs->tilt_y   = 0;
+        prefs->tilt_z   = 0;
+        prefs->tilt_scale   = 1;
+        
+	prefs->trans 	=  	FALSE;
+        prefs->trans_x   = 0;
+        prefs->trans_y   = 0;
+        prefs->trans_z   = 0;
+        
+        prefs->test = FALSE;
+        prefs->test_p0 = 0;
+        prefs->test_p1 = 0;
+        prefs->test_p2 = 0;
+        prefs->test_p3 = 0;
+
 	prefs->shear 	= prefs->resize 	= FALSE;
 	prefs->shear_x 	= prefs->shear_y 	= 0.0;
 	prefs->width 	= prefs->height 	= 0;
