@@ -852,7 +852,7 @@ void SetImageDefaults(Image *im){
 	im->formatParamCount    = 0;
 	bzero(im->formatParam, sizeof(im->formatParam));
 	im->precomputedCount    = 0;
-	bzero(im->formatParam, sizeof(im->precomputedValue));
+	bzero(im->precomputedValue, sizeof(im->precomputedValue));
         im->dataformat          = _RGB;
         im->hfov                = 0.0;
         im->yaw                 = 0.0;
