@@ -151,11 +151,11 @@ JNIEXPORT void JNICALL Java_pteditor_CExtract
 	ap.pano.hfov	= phfov;
 
 	if( ap.pano.format == _equirectangular ){ // extract image from panorama	
-		ap.im.width = (hfov / ap.pano.hfov) * 2 * ap.pano.width;
+		ap.im.width = (pt_int32)((hfov / ap.pano.hfov) * 2 * ap.pano.width);
 	}else{ // extract image from fisheye source
-		ap.im.width = (hfov / ap.pano.hfov) * ap.pano.width;
+		ap.im.width = (pt_int32)((hfov / ap.pano.hfov) * ap.pano.width);
 	}
-	ap.im.height	= (double)ap.im.width / aspect;
+	ap.im.height	= (pt_int32)((double)ap.im.width / aspect);
 	ap.im.format	= _rectilinear;
 	ap.im.yaw		= yaw;
 	ap.im.pitch		= pitch;
@@ -163,7 +163,8 @@ JNIEXPORT void JNICALL Java_pteditor_CExtract
 
 	if( readPrefs( (char*) &spref, _sizep ) != 0 )
 		SetSizeDefaults	( &spref );
-	
+
+	memset(&Tr, 0, sizeof(TrformStr));
 	Tr.src 	= pano;
 	Tr.dest	= &dest;
 
@@ -171,6 +172,7 @@ JNIEXPORT void JNICALL Java_pteditor_CExtract
 	Tr.mode					= _usedata + _show_progress + _honor_valid;
 	Tr.interpolator			= spref.interpolator;
 	Tr.gamma				= spref.gamma;
+    Tr.fastStep             = spref.fastStep;
 	Tr.data					= (void*) &ap;
 
 	Tr.success = 1;
@@ -254,6 +256,7 @@ JNIEXPORT void JNICALL Java_pteditor_CInsert
 	if( readPrefs( (char*) &spref, _sizep ) != 0 )
 		SetSizeDefaults	( &spref );
 	
+  memset(&Tr, 0, sizeof(TrformStr));
 	Tr.src 	= &src;
 	Tr.dest	= &dest;
 
@@ -261,6 +264,7 @@ JNIEXPORT void JNICALL Java_pteditor_CInsert
 	Tr.mode					= _usedata + _show_progress + _destSupplied;
 	Tr.interpolator			= spref.interpolator;
 	Tr.gamma				= spref.gamma;
+    Tr.fastStep             = spref.fastStep;
 	Tr.data					= (void*) &ap;
 
 	Tr.success = 1;
