@@ -45,8 +45,8 @@ typedef struct
 void getCropInformationFromTiff(TIFF *tif, CropInfo *c);
 void setCropInformationInTiff(TIFF *tiffFile, CropInfo *crop_info);
 
-int TiffGetImageParameters(TIFF *tiffFile, pt_tiff_parms *tiffData);
-int TiffSetImageParameters(TIFF *tiffFile, pt_tiff_parms *tiffData);
+//int TiffGetImageParameters(TIFF *tiffFile, pt_tiff_parms *tiffData);
+//int TiffSetImageParameters(TIFF *tiffFile, pt_tiff_parms *tiffData);
 
 int panoTiffUnCrop(char *inputFile, char *outputFile, pano_cropping_parms *croppingParms);
 int panoTiffCrop(char *inputFile, char *outputFile, pano_cropping_parms *croppingParms);
