@@ -110,24 +110,13 @@ void transForm_aa( TrformStr *TrPtr, fDesc *fD,fDesc *finvD, int color, int imag
 
 
 // Arrays used for Gamma correction
-
-
 PTGamma glu; // Lookup table
 
-
-// FS+
-// used for fast pixel transform. It is the width of the starting step for linear interpolation
-// a value of 0 disables the fast transform
-int fastTransformStep = 0;
-
 // prototype to avoid a warning: the function is defined in morpher.c
 int getLastCurTriangle();
 
-// FS-
-
 
 // Some locally needed math functions
-
 static double 	sinc		( double x );
 static double 	cubic01		( double x );
 static double 	cubic12		( double x ); 
@@ -337,7 +326,7 @@ int SetUpGamma( double pgamma, unsigned int psize)
 
 unsigned short gamma_correct( double pix )
 {
-	int k = glu.ChannelStretch * pix;
+	int k = (int)(glu.ChannelStretch * pix);
 	if( k < 0 )
 		return 0;
 	if( k > glu.GammaSize - 1 )
@@ -345,9 +334,9 @@ unsigned short gamma_correct( double pix )
 	return (glu.Gamma)[ k ] ;
 }
 
-#define gamma_char(pix) gamma_correct(pix)
-#define gamma_short(pix) gamma_correct(pix)
-#define gamma_float(pix) pix
+#define gamma_char(pix) (char)(gamma_correct(pix))
+#define gamma_short(pix) (short)(gamma_correct(pix))
+#define gamma_float(pix) (float)(pix)
 
 #define degamma_char(pix) glu.DeGamma[pix]
 #define degamma_short(pix) glu.DeGamma[pix]
@@ -528,8 +517,6 @@ unsigned short gamma_correct( double pix )
 ;
 
 
-
-
 static double sinc( double x )
 {
 	x *= PI;
@@ -814,7 +801,6 @@ static void sinc1024_32( unsigned char *dst, unsigned char **rgb,
 #undef unsigned
 }
 		
-
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 // FS+ start of functions used to compute the pixel tranform from dest to source using linear interpolation
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -948,11 +934,9 @@ void ComputePartialRowCoords( double *ax, double *ay, int *trinum, char *avalid,
 // the array elements lie in the interval [0, asize], the image elements in [destRect.left, destRect.right]: the offset parameter
 //   is used for the conversion
 void ComputeRowCoords( double *ax, double *ay, int *trinum, char *avalid, pt_int32 asize, long offset, double w2, double y_d, 
-						  fDesc *fD, double sw2, double sh2, double min_x, double max_x, double min_y, double max_y ) {
+						  fDesc *fD, double sw2, double sh2, double min_x, double max_x, double min_y, double max_y, int STEP_WIDTH) {
 
-	// initial distance betwen correctly computed points. The distance will be reduced if needed.
-//	int STEP_WIDTH = 40;
-	int STEP_WIDTH = fastTransformStep;
+	// STEP_WIDTH is initial distance betwen correctly computed points. The distance will be reduced if needed.
 
 	pt_int32 x;
 
@@ -1067,7 +1051,7 @@ void MyTransForm( TrformStr *TrPtr, fDesc *fD, int color, int imageNum)
 	char *avalid = NULL;			// is the pixel valid?
 	double maxErrX, maxErrY;
 	long offset;
-//	int useFastTransform;	// true if we will use the new fast pixel transformation
+    int FastTransform = TrPtr->fastStep; // non 0 if we will use the new fast pixel transformation
 	int evaluateError = FALSE;		// true if we want to write a file with the transformation errors
 	// FS-
 	//////////////////////////////////////////////////////////////////////////
@@ -1177,6 +1161,20 @@ void MyTransForm( TrformStr *TrPtr, fDesc *fD, int color, int imageNum)
 	dest = *TrPtr->dest->data;
 	src  = *TrPtr->src->data; // is locked
 
+    //MRDL: There seems to be a strange bug somewhere that
+    //corrupts the first three bytes of each source image.
+    //Rather than looking like this (ARGB ARGB ARGB ARGB):
+    //   255 128 128 128   255 128 128 128   255 128 128 128   255 128 128 128
+    //They look like this:
+    //   255 255 255 255   255 128 255 128   255 128 128 255   255 128 128 128
+    //So fix up the first few bytes to workaround this if file is large than 3 bytes
+    if ((mix+1) * (miy+1) > 3)
+    {
+        memcpy( src                      , src + (BytesPerPixel * 3), BytesPerPixel);
+        memcpy( src + (BytesPerPixel * 1), src + (BytesPerPixel * 3), BytesPerPixel);
+        memcpy( src + (BytesPerPixel * 2), src + (BytesPerPixel * 3), BytesPerPixel);        
+    }
+    
 	if(TrPtr->mode & _show_progress){
 		switch(color){
 			case 0:
@@ -1265,14 +1263,16 @@ void MyTransForm( TrformStr *TrPtr, fDesc *fD, int color, int imageNum)
 			while( !feof(fp) && buf != NULL ) {
 				//s = strupr( buf );	commented out because it causes linking problems with the microsoft compiler
 				if( strncmp( s, "FAST_TRANSFORM", 14 )  == 0 )
-					fastTransformStep = FAST_TRANSFORM_STEP_NORMAL;
+					FastTransform = FAST_TRANSFORM_STEP_NORMAL;
+				if( strncmp( s, "MORPH_TRANSFORM", 15 )  == 0 )
+					FastTransform = FAST_TRANSFORM_STEP_MORPH;
 				if( strncmp( s, "EVALUATE_ERROR", 14 )  == 0 )
 					evaluateError = TRUE;
 				s = fgets( buf, 98, fp );
 			}
 			fclose( fp );
 		}
-		if( fastTransformStep == 0 ) evaluateError = FALSE;	// only evaluate error if fast transform is activated
+		if( FastTransform == 0 ) evaluateError = FALSE;	// only evaluate error if fast transform is activated
 	}
 	// FS-
 
@@ -1300,8 +1300,8 @@ void MyTransForm( TrformStr *TrPtr, fDesc *fD, int color, int imageNum)
 		cy  = (y-destRect.top) * TrPtr->dest->bytesPerLine;	
 		
 		// FS+ computes the transform for this row using linear interpolation
-		if( fastTransformStep != 0 || evaluateError )
-			ComputeRowCoords( ax, ay, trinum, avalid, destRect.right - destRect.left + 1, offset, w2, y_d, fD, sw2, sh2, min_x, max_x, min_y, max_y );
+		if( FastTransform != 0 || evaluateError )
+			ComputeRowCoords( ax, ay, trinum, avalid, destRect.right - destRect.left + 1, offset, w2, y_d, fD, sw2, sh2, min_x, max_x, min_y, max_y, FastTransform);
 		// FS-
 
 		for(x=destRect.left; x<destRect.right; x++){
@@ -1310,7 +1310,7 @@ void MyTransForm( TrformStr *TrPtr, fDesc *fD, int color, int imageNum)
 			coeff = cy  + BytesPerPixel * (x-destRect.left);		
 
 			// FS+
-			if( fastTransformStep == 0 || evaluateError ) {
+			if( FastTransform == 0 || evaluateError ) {
 				// Convert destination screen coordinates to cartesian coordinates.			
 				x_d = (double) x - w2 ;
 				
@@ -1984,7 +1984,7 @@ void transForm_aa( TrformStr *TrPtr, fDesc *fD,fDesc *finvD, int color, int imag
 	ffQueueItem *ffStack;
 	int			srcWidth; 
 	int			srcHeight; 
-	unsigned int *ffIsInQueue;
+	pt_uint32 *ffIsInQueue;
 
 	int ccx,ccy;
 	double d,sd,ox,oy;
@@ -2284,10 +2284,10 @@ void transForm_aa( TrformStr *TrPtr, fDesc *fD,fDesc *finvD, int color, int imag
 				double weight,w,rd,gd,bd;
 				pt_uint32 *ptui;
 
-				bx=floor(orgDx + sw2);
-				ex=ceil(orgDx + sw2);
-				by=floor(orgDy + sh2);  
-				ey=ceil(orgDy + sh2);
+				bx = (int)(floor(orgDx + sw2));
+				ex = (int)(ceil(orgDx + sw2));
+				by = (int)(floor(orgDy + sh2));
+				ey = (int)(ceil(orgDy + sh2));
 				
 				// Clear only the modified floodfill markers
 				ptui=&ffIsInQueue[ptmod_first];
