@@ -38,9 +38,11 @@
 
 #define		GenDialog( VarType, DlgRes, Title,  SetControl,SText,			\
 			GText, DlgAction, WinFunc)										\
-																			\
 			return( FALSE );
 
+void SetWindowOwner(void * Owner);
+void CenterDialog(void * hDlg);
+
 #define		kSetRemapPrefs_dlg					"REMAP"	
 #define		kSetRemapPrefs_InRect				350
 #define		kSetRemapPrefs_InPano				351
